# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.webhooks_api import WebhooksApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self):
        self.api = WebhooksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_store_id_webhooks_post(self):
        """Test case for api_v1_stores_store_id_webhooks_post

        Create a new webhook  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_delete(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_delete

        Delete a webhook  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_get(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_get

        Get a webhook delivery  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_redeliver_post(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_redeliver_post

        Redeliver the delivery  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_request_get(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_request_get

        Get the delivery's request  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_deliveries_get(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_deliveries_get

        Get latest deliveries  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_put(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_put

        Update a webhook  # noqa: E501
        """
        pass

    def test_webhokks_get_webhook(self):
        """Test case for webhokks_get_webhook

        Get a webhook of a store  # noqa: E501
        """
        pass

    def test_webhokks_get_webhooks(self):
        """Test case for webhokks_get_webhooks

        Get webhooks of a store  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
