# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.stores__payout_processors_api import StoresPayoutProcessorsApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStoresPayoutProcessorsApi(unittest.TestCase):
    """StoresPayoutProcessorsApi unit test stubs"""

    def setUp(self):
        self.api = StoresPayoutProcessorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors(self):
        """Test case for greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors

        Get configured store Lightning automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors_0(self):
        """Test case for greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors_0

        Get configured store Lightning automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_lightning_payout_processors_controller_update_store_lightning_automated_payout_processor(self):
        """Test case for greenfield_store_automated_lightning_payout_processors_controller_update_store_lightning_automated_payout_processor

        Update configured store Lightning automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors(self):
        """Test case for greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors

        Get configured store onchain automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors_0(self):
        """Test case for greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors_0

        Get configured store onchain automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor(self):
        """Test case for greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor

        Update configured store onchain automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor_0(self):
        """Test case for greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor_0

        Update configured store onchain automated payout processors  # noqa: E501
        """
        pass

    def test_store_payout_processors_get_store_payout_processors(self):
        """Test case for store_payout_processors_get_store_payout_processors

        Get store configured payout processors  # noqa: E501
        """
        pass

    def test_store_payout_processors_remove_store_payout_processor(self):
        """Test case for store_payout_processors_remove_store_payout_processor

        Remove store configured payout processor  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
