# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LightningInvoiceData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'status': 'LightningInvoiceStatus',
        'bolt11': 'str',
        'paid_at': 'AllOfLightningInvoiceDataPaidAt',
        'expires_at': 'AllOfLightningInvoiceDataExpiresAt',
        'amount': 'str',
        'amount_received': 'str'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'bolt11': 'BOLT11',
        'paid_at': 'paidAt',
        'expires_at': 'expiresAt',
        'amount': 'amount',
        'amount_received': 'amountReceived'
    }

    def __init__(self, id=None, status=None, bolt11=None, paid_at=None, expires_at=None, amount=None, amount_received=None):  # noqa: E501
        """LightningInvoiceData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._status = None
        self._bolt11 = None
        self._paid_at = None
        self._expires_at = None
        self._amount = None
        self._amount_received = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if bolt11 is not None:
            self.bolt11 = bolt11
        if paid_at is not None:
            self.paid_at = paid_at
        if expires_at is not None:
            self.expires_at = expires_at
        if amount is not None:
            self.amount = amount
        if amount_received is not None:
            self.amount_received = amount_received

    @property
    def id(self):
        """Gets the id of this LightningInvoiceData.  # noqa: E501

        The invoice's ID  # noqa: E501

        :return: The id of this LightningInvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LightningInvoiceData.

        The invoice's ID  # noqa: E501

        :param id: The id of this LightningInvoiceData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this LightningInvoiceData.  # noqa: E501


        :return: The status of this LightningInvoiceData.  # noqa: E501
        :rtype: LightningInvoiceStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this LightningInvoiceData.


        :param status: The status of this LightningInvoiceData.  # noqa: E501
        :type: LightningInvoiceStatus
        """

        self._status = status

    @property
    def bolt11(self):
        """Gets the bolt11 of this LightningInvoiceData.  # noqa: E501

        The BOLT11 representation of the invoice  # noqa: E501

        :return: The bolt11 of this LightningInvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._bolt11

    @bolt11.setter
    def bolt11(self, bolt11):
        """Sets the bolt11 of this LightningInvoiceData.

        The BOLT11 representation of the invoice  # noqa: E501

        :param bolt11: The bolt11 of this LightningInvoiceData.  # noqa: E501
        :type: str
        """

        self._bolt11 = bolt11

    @property
    def paid_at(self):
        """Gets the paid_at of this LightningInvoiceData.  # noqa: E501

        The unix timestamp when the invoice got paid  # noqa: E501

        :return: The paid_at of this LightningInvoiceData.  # noqa: E501
        :rtype: AllOfLightningInvoiceDataPaidAt
        """
        return self._paid_at

    @paid_at.setter
    def paid_at(self, paid_at):
        """Sets the paid_at of this LightningInvoiceData.

        The unix timestamp when the invoice got paid  # noqa: E501

        :param paid_at: The paid_at of this LightningInvoiceData.  # noqa: E501
        :type: AllOfLightningInvoiceDataPaidAt
        """

        self._paid_at = paid_at

    @property
    def expires_at(self):
        """Gets the expires_at of this LightningInvoiceData.  # noqa: E501

        The unix timestamp when the invoice expires  # noqa: E501

        :return: The expires_at of this LightningInvoiceData.  # noqa: E501
        :rtype: AllOfLightningInvoiceDataExpiresAt
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this LightningInvoiceData.

        The unix timestamp when the invoice expires  # noqa: E501

        :param expires_at: The expires_at of this LightningInvoiceData.  # noqa: E501
        :type: AllOfLightningInvoiceDataExpiresAt
        """

        self._expires_at = expires_at

    @property
    def amount(self):
        """Gets the amount of this LightningInvoiceData.  # noqa: E501

        The amount of the invoice in millisatoshi  # noqa: E501

        :return: The amount of this LightningInvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this LightningInvoiceData.

        The amount of the invoice in millisatoshi  # noqa: E501

        :param amount: The amount of this LightningInvoiceData.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def amount_received(self):
        """Gets the amount_received of this LightningInvoiceData.  # noqa: E501

        The amount received in millisatoshi  # noqa: E501

        :return: The amount_received of this LightningInvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._amount_received

    @amount_received.setter
    def amount_received(self, amount_received):
        """Sets the amount_received of this LightningInvoiceData.

        The amount received in millisatoshi  # noqa: E501

        :param amount_received: The amount_received of this LightningInvoiceData.  # noqa: E501
        :type: str
        """

        self._amount_received = amount_received

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LightningInvoiceData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LightningInvoiceData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
