# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.stores__users_api import StoresUsersApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStoresUsersApi(unittest.TestCase):
    """StoresUsersApi unit test stubs"""

    def setUp(self):
        self.api = StoresUsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_stores_add_store_user(self):
        """Test case for stores_add_store_user

        Add a store user  # noqa: E501
        """
        pass

    def test_stores_get_store_users(self):
        """Test case for stores_get_store_users

        Get store users  # noqa: E501
        """
        pass

    def test_stores_remove_store_user(self):
        """Test case for stores_remove_store_user

        Remove Store User  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
