# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateOnChainPaymentMethodRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'derivation_scheme': 'str',
        'label': 'str',
        'account_key_path': 'str'
    }

    attribute_map = {
        'derivation_scheme': 'derivationScheme',
        'label': 'label',
        'account_key_path': 'accountKeyPath'
    }

    def __init__(self, derivation_scheme=None, label=None, account_key_path=None):  # noqa: E501
        """UpdateOnChainPaymentMethodRequest - a model defined in Swagger"""  # noqa: E501
        self._derivation_scheme = None
        self._label = None
        self._account_key_path = None
        self.discriminator = None
        if derivation_scheme is not None:
            self.derivation_scheme = derivation_scheme
        if label is not None:
            self.label = label
        if account_key_path is not None:
            self.account_key_path = account_key_path

    @property
    def derivation_scheme(self):
        """Gets the derivation_scheme of this UpdateOnChainPaymentMethodRequest.  # noqa: E501

        The derivation scheme  # noqa: E501

        :return: The derivation_scheme of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :rtype: str
        """
        return self._derivation_scheme

    @derivation_scheme.setter
    def derivation_scheme(self, derivation_scheme):
        """Sets the derivation_scheme of this UpdateOnChainPaymentMethodRequest.

        The derivation scheme  # noqa: E501

        :param derivation_scheme: The derivation_scheme of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :type: str
        """

        self._derivation_scheme = derivation_scheme

    @property
    def label(self):
        """Gets the label of this UpdateOnChainPaymentMethodRequest.  # noqa: E501

        A label that will be shown in the UI  # noqa: E501

        :return: The label of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this UpdateOnChainPaymentMethodRequest.

        A label that will be shown in the UI  # noqa: E501

        :param label: The label of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def account_key_path(self):
        """Gets the account_key_path of this UpdateOnChainPaymentMethodRequest.  # noqa: E501

        The wallet fingerprint followed by the keypath to derive the account key used for signing operation or creating PSBTs  # noqa: E501

        :return: The account_key_path of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :rtype: str
        """
        return self._account_key_path

    @account_key_path.setter
    def account_key_path(self, account_key_path):
        """Sets the account_key_path of this UpdateOnChainPaymentMethodRequest.

        The wallet fingerprint followed by the keypath to derive the account key used for signing operation or creating PSBTs  # noqa: E501

        :param account_key_path: The account_key_path of this UpdateOnChainPaymentMethodRequest.  # noqa: E501
        :type: str
        """

        self._account_key_path = account_key_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateOnChainPaymentMethodRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateOnChainPaymentMethodRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
