# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreatePayoutRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'destination': 'str',
        'amount': 'str',
        'payment_method': 'str'
    }

    attribute_map = {
        'destination': 'destination',
        'amount': 'amount',
        'payment_method': 'paymentMethod'
    }

    def __init__(self, destination=None, amount=None, payment_method=None):  # noqa: E501
        """CreatePayoutRequest - a model defined in Swagger"""  # noqa: E501
        self._destination = None
        self._amount = None
        self._payment_method = None
        self.discriminator = None
        if destination is not None:
            self.destination = destination
        if amount is not None:
            self.amount = amount
        if payment_method is not None:
            self.payment_method = payment_method

    @property
    def destination(self):
        """Gets the destination of this CreatePayoutRequest.  # noqa: E501

        The destination of the payout (can be an address or a BIP21 url)  # noqa: E501

        :return: The destination of this CreatePayoutRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this CreatePayoutRequest.

        The destination of the payout (can be an address or a BIP21 url)  # noqa: E501

        :param destination: The destination of this CreatePayoutRequest.  # noqa: E501
        :type: str
        """

        self._destination = destination

    @property
    def amount(self):
        """Gets the amount of this CreatePayoutRequest.  # noqa: E501

        The amount of the payout in the currency of the pull payment (eg. USD).  # noqa: E501

        :return: The amount of this CreatePayoutRequest.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CreatePayoutRequest.

        The amount of the payout in the currency of the pull payment (eg. USD).  # noqa: E501

        :param amount: The amount of this CreatePayoutRequest.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def payment_method(self):
        """Gets the payment_method of this CreatePayoutRequest.  # noqa: E501

        The payment method of the payout  # noqa: E501

        :return: The payment_method of this CreatePayoutRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this CreatePayoutRequest.

        The payment method of the payout  # noqa: E501

        :param payment_method: The payment_method of this CreatePayoutRequest.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreatePayoutRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePayoutRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
