# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.models.application_server_info_node_status_data import ApplicationServerInfoNodeStatusData  # noqa: E501
from pygreenfield.rest import ApiException


class TestApplicationServerInfoNodeStatusData(unittest.TestCase):
    """ApplicationServerInfoNodeStatusData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApplicationServerInfoNodeStatusData(self):
        """Test ApplicationServerInfoNodeStatusData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.application_server_info_node_status_data.ApplicationServerInfoNodeStatusData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
