# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.api_keys_api import APIKeysApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestAPIKeysApi(unittest.TestCase):
    """APIKeysApi unit test stubs"""

    def setUp(self):
        self.api = APIKeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_api_keys_apikey_delete(self):
        """Test case for api_v1_api_keys_apikey_delete

        Revoke an API Key  # noqa: E501
        """
        pass

    def test_api_v1_api_keys_current_delete(self):
        """Test case for api_v1_api_keys_current_delete

        Revoke the current API Key  # noqa: E501
        """
        pass

    def test_api_v1_api_keys_current_get(self):
        """Test case for api_v1_api_keys_current_get

        Get the current API Key information  # noqa: E501
        """
        pass

    def test_api_v1_api_keys_post(self):
        """Test case for api_v1_api_keys_post

        Create a new API Key  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
