# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.stores_api import StoresApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStoresApi(unittest.TestCase):
    """StoresApi unit test stubs"""

    def setUp(self):
        self.api = StoresApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_post(self):
        """Test case for api_v1_stores_post

        Create a new store  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_delete(self):
        """Test case for api_v1_stores_store_id_delete

        Remove Store  # noqa: E501
        """
        pass

    def test_stores_get_store(self):
        """Test case for stores_get_store

        Get store  # noqa: E501
        """
        pass

    def test_stores_get_stores(self):
        """Test case for stores_get_stores

        Get stores  # noqa: E501
        """
        pass

    def test_stores_update_store(self):
        """Test case for stores_update_store

        Update store  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
