# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.models.v1_users_body import V1UsersBody  # noqa: E501
from pygreenfield.rest import ApiException


class TestV1UsersBody(unittest.TestCase):
    """V1UsersBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1UsersBody(self):
        """Test V1UsersBody"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.v1_users_body.V1UsersBody()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
