# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.store_payment_methods__lightning_network_api import StorePaymentMethodsLightningNetworkApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStorePaymentMethodsLightningNetworkApi(unittest.TestCase):
    """StorePaymentMethodsLightningNetworkApi unit test stubs"""

    def setUp(self):
        self.api = StorePaymentMethodsLightningNetworkApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_store_id_payment_methods_lightning_network_crypto_code_delete(self):
        """Test case for api_v1_stores_store_id_payment_methods_lightning_network_crypto_code_delete

        Remove store Lightning Network payment method  # noqa: E501
        """
        pass

    def test_store_lightning_network_payment_methods_get_lightning_network_payment_method(self):
        """Test case for store_lightning_network_payment_methods_get_lightning_network_payment_method

        Get store Lightning Network payment method  # noqa: E501
        """
        pass

    def test_store_lightning_network_payment_methods_get_lightning_network_payment_methods(self):
        """Test case for store_lightning_network_payment_methods_get_lightning_network_payment_methods

        Get store Lightning Network payment methods  # noqa: E501
        """
        pass

    def test_store_lightning_network_payment_methods_update_lightning_network_payment_method(self):
        """Test case for store_lightning_network_payment_methods_update_lightning_network_payment_method

        Update store Lightning Network payment method  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
