# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.payment_requests_api import PaymentRequestsApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestPaymentRequestsApi(unittest.TestCase):
    """PaymentRequestsApi unit test stubs"""

    def setUp(self):
        self.api = PaymentRequestsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_payment_requests_archive_payment_request(self):
        """Test case for payment_requests_archive_payment_request

        Archive payment request  # noqa: E501
        """
        pass

    def test_payment_requests_create_payment_request(self):
        """Test case for payment_requests_create_payment_request

        Create a new payment request  # noqa: E501
        """
        pass

    def test_payment_requests_get_payment_request(self):
        """Test case for payment_requests_get_payment_request

        Get payment request  # noqa: E501
        """
        pass

    def test_payment_requests_get_payment_requests(self):
        """Test case for payment_requests_get_payment_requests

        Get payment requests  # noqa: E501
        """
        pass

    def test_payment_requests_update_payment_request(self):
        """Test case for payment_requests_update_payment_request

        Update payment request  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
