# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.server_info_api import ServerInfoApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestServerInfoApi(unittest.TestCase):
    """ServerInfoApi unit test stubs"""

    def setUp(self):
        self.api = ServerInfoApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_server_info_get_server_info(self):
        """Test case for server_info_get_server_info

        Get server info  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
