# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OnChainWalletOverviewData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'balance': 'str',
        'unconfirmed_balance': 'str',
        'confirmed_balance': 'str'
    }

    attribute_map = {
        'balance': 'balance',
        'unconfirmed_balance': 'unconfirmedBalance',
        'confirmed_balance': 'confirmedBalance'
    }

    def __init__(self, balance=None, unconfirmed_balance=None, confirmed_balance=None):  # noqa: E501
        """OnChainWalletOverviewData - a model defined in Swagger"""  # noqa: E501
        self._balance = None
        self._unconfirmed_balance = None
        self._confirmed_balance = None
        self.discriminator = None
        if balance is not None:
            self.balance = balance
        if unconfirmed_balance is not None:
            self.unconfirmed_balance = unconfirmed_balance
        if confirmed_balance is not None:
            self.confirmed_balance = confirmed_balance

    @property
    def balance(self):
        """Gets the balance of this OnChainWalletOverviewData.  # noqa: E501

        The total current balance of the wallet  # noqa: E501

        :return: The balance of this OnChainWalletOverviewData.  # noqa: E501
        :rtype: str
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this OnChainWalletOverviewData.

        The total current balance of the wallet  # noqa: E501

        :param balance: The balance of this OnChainWalletOverviewData.  # noqa: E501
        :type: str
        """

        self._balance = balance

    @property
    def unconfirmed_balance(self):
        """Gets the unconfirmed_balance of this OnChainWalletOverviewData.  # noqa: E501

        The current unconfirmed balance of the wallet  # noqa: E501

        :return: The unconfirmed_balance of this OnChainWalletOverviewData.  # noqa: E501
        :rtype: str
        """
        return self._unconfirmed_balance

    @unconfirmed_balance.setter
    def unconfirmed_balance(self, unconfirmed_balance):
        """Sets the unconfirmed_balance of this OnChainWalletOverviewData.

        The current unconfirmed balance of the wallet  # noqa: E501

        :param unconfirmed_balance: The unconfirmed_balance of this OnChainWalletOverviewData.  # noqa: E501
        :type: str
        """

        self._unconfirmed_balance = unconfirmed_balance

    @property
    def confirmed_balance(self):
        """Gets the confirmed_balance of this OnChainWalletOverviewData.  # noqa: E501

        The current confirmed balance of the wallet  # noqa: E501

        :return: The confirmed_balance of this OnChainWalletOverviewData.  # noqa: E501
        :rtype: str
        """
        return self._confirmed_balance

    @confirmed_balance.setter
    def confirmed_balance(self, confirmed_balance):
        """Sets the confirmed_balance of this OnChainWalletOverviewData.

        The current confirmed balance of the wallet  # noqa: E501

        :param confirmed_balance: The confirmed_balance of this OnChainWalletOverviewData.  # noqa: E501
        :type: str
        """

        self._confirmed_balance = confirmed_balance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OnChainWalletOverviewData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OnChainWalletOverviewData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
