# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.store_wallet__on_chain_api import StoreWalletOnChainApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStoreWalletOnChainApi(unittest.TestCase):
    """StoreWalletOnChainApi unit test stubs"""

    def setUp(self):
        self.api = StoreWalletOnChainApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_store_on_chain_wallets_create_on_chain_transaction(self):
        """Test case for store_on_chain_wallets_create_on_chain_transaction

        Create store on-chain wallet transaction  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_get_on_chain_fee_rate(self):
        """Test case for store_on_chain_wallets_get_on_chain_fee_rate

        Get store on-chain wallet fee rate  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_get_on_chain_wallet_receive_address(self):
        """Test case for store_on_chain_wallets_get_on_chain_wallet_receive_address

        Get store on-chain wallet address  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_get_on_chain_wallet_transaction(self):
        """Test case for store_on_chain_wallets_get_on_chain_wallet_transaction

        Get store on-chain wallet transaction  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_get_on_chain_wallet_utx_os(self):
        """Test case for store_on_chain_wallets_get_on_chain_wallet_utx_os

        Get store on-chain wallet UTXOS  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_patch_on_chain_wallet_transaction(self):
        """Test case for store_on_chain_wallets_patch_on_chain_wallet_transaction

        Patch store on-chain wallet transaction info  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_show_on_chain_wallet_overview(self):
        """Test case for store_on_chain_wallets_show_on_chain_wallet_overview

        Get store on-chain wallet overview  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_show_on_chain_wallet_transactions(self):
        """Test case for store_on_chain_wallets_show_on_chain_wallet_transactions

        Get store on-chain wallet transactions  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address(self):
        """Test case for store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address

        UnReserve last store on-chain wallet address  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
