# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.store_payment_methods__on_chain_api import StorePaymentMethodsOnChainApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStorePaymentMethodsOnChainApi(unittest.TestCase):
    """StorePaymentMethodsOnChainApi unit test stubs"""

    def setUp(self):
        self.api = StorePaymentMethodsOnChainApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_store_id_payment_methods_onchain_crypto_code_delete(self):
        """Test case for api_v1_stores_store_id_payment_methods_onchain_crypto_code_delete

        Remove store on-chain payment method  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_generate_on_chain_wallet(self):
        """Test case for store_on_chain_payment_methods_generate_on_chain_wallet

        Generate store on-chain wallet  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_get_on_chain_payment_method(self):
        """Test case for store_on_chain_payment_methods_get_on_chain_payment_method

        Get store on-chain payment method  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_get_on_chain_payment_method_preview(self):
        """Test case for store_on_chain_payment_methods_get_on_chain_payment_method_preview

        Preview store on-chain payment method addresses  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_get_on_chain_payment_methods(self):
        """Test case for store_on_chain_payment_methods_get_on_chain_payment_methods

        Get store on-chain payment methods  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_post_on_chain_payment_method_preview(self):
        """Test case for store_on_chain_payment_methods_post_on_chain_payment_method_preview

        Preview proposed store on-chain payment method addresses  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_update_on_chain_payment_method(self):
        """Test case for store_on_chain_payment_methods_update_on_chain_payment_method

        Update store on-chain payment method  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
